@@ -295,7 +295,7 @@ test_that("Success run MultAdj with Case 1A", {
     # Set the seed of R‘s random number generator.
   # It also takes effect to Rcpp randome generation functions.
   # https://stackoverflow.com/questions/60119621/get-the-same-sample-of-integers-from-rcpp-as-base-r
-  #RNGkind(sample.kind = "Rounding")
+  suppressWarnings(RNGkind(sample.kind = "Rounding"))
   set.seed(5)
 
   # Run simulations
